# Generated by Django 4.1.2 on 2022-10-21 21:47

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("wagtaildocs", "0012_uploadeddocument"),
        ("wagtailcore", "0066_collection_management_permissions"),
    ]

    operations = [
        migrations.CreateModel(
            name="QRCodePage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.page",
                    ),
                ),
                (
                    "qr_code_svg",
                    models.TextField(blank=True, null=True, verbose_name="QR Code SVG"),
                ),
                (
                    "qr_code_usage",
                    models.IntegerField(default=0, verbose_name="QR Code Usage Count"),
                ),
                (
                    "qr_code_eps",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="wagtaildocs.document",
                        verbose_name="QR Code EPS",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page", models.Model),
        ),
    ]
